@@ -476,23 +476,6 @@ ev_previewer_window_dispose (GObject *object)
 	G_OBJECT_CLASS (ev_previewer_window_parent_class)->dispose (object);
 }
 
-static gchar*
-data_dir (void)
-{
-	gchar *datadir;
-#ifdef G_OS_WIN32
-	gchar *dir;
-
-	dir = g_win32_get_package_installation_directory_of_module (NULL);
-	datadir = g_build_filename (dir, "share", "evince", NULL);
-	g_free (dir);
-#else
-	datadir = g_strdup (EVINCEDATADIR);
-#endif
-
-       return datadir;
-}
-
 static void
 ev_previewer_window_init (EvPreviewerWindow *window)
 {
@@ -527,7 +510,6 @@ ev_previewer_window_constructor (GType                  type,
 	GtkWidget         *toolbar;
 	GtkAction         *action;
 	GError            *error = NULL;
-	gchar             *datadir, *ui_path;
 	gdouble            dpi;
 
 	object = G_OBJECT_CLASS (ev_previewer_window_parent_class)->constructor (type,
@@ -580,14 +562,9 @@ ev_previewer_window_constructor (GType                  type,
 					    window->accels_group, 1);
 	gtk_window_add_accel_group (GTK_WINDOW (window),
 				    gtk_ui_manager_get_accel_group (window->ui_manager));
-	datadir = data_dir ();
-	ui_path = g_build_filename (datadir, "evince-previewer-ui.xml", NULL);
-	if (!gtk_ui_manager_add_ui_from_file (window->ui_manager, ui_path, &error)) {
-		g_warning ("Failed to load ui from evince-previewer-ui.xml: %s", error->message);
-		g_error_free (error);
-	}
-	g_free (ui_path);
-	g_free (datadir);
+
+        gtk_ui_manager_add_ui_from_resource (window->ui_manager, "/org/gnome/evince/previewer/ui/previewer.xml", &error);
+        g_assert_no_error (error);
 
 	/* GTKUIManager connects actions accels only for menu items,
 	 * but not for tool items. See bug #612972.
